@@ -9,21 +9,6 @@ Created on Sat Feb  5 20:38:43 2022
 import pandas as pd
 
 
-def check_csv(fname, key="key", alias="alias"):
-    df = pd.read_csv(fname, usecols=[key, alias])
-    inds = df.duplicated(subset=["alias"])
-    if any(inds):
-        df2 = df.loc[inds]
-        raise KeyError("Duplate aliases: ", df2["alias"])
-
-
-def canonical(aliases):
-    """Return an Aliases with only last keys for duplicate values"""
-    uniques_inv = {v: k for k, v in aliases.items()}
-    uniques = {v: k for k, v in uniques_inv.items()}
-    return Aliases(uniques)
-
-
 class Aliases(dict):
     def translate(self, dct):
         out = {}
@@ -39,6 +24,10 @@ class Aliases(dict):
 
     def add_csv(self, fname, key="key", alias="alias", **kwargs):
         df = pd.read_csv(fname, usecols=[key, alias])
+        inds = df.duplicated(subset=["alias"])
+        if any(inds):
+            df2 = df.loc[inds]
+            raise KeyError("Duplate aliases: ", df2["alias"])
         dct = {r[alias]: r[key] for i, r in df.iterrows()}
         self.update(dct)
 
